@@ -1,7 +1,7 @@
 import google.cloud.logging
 import google.auth
 import threading
-import time, os
+import time, os, random
 
 from uuid import uuid4
 from falcon import Request, Response
@@ -25,6 +25,10 @@ class _Context:
     @property
     def trace(self):
         return getattr(self._thread_local, 'trace', None)
+    
+    @property
+    def trace_context(self):
+        return getattr(self._thread_local, 'trace_context', None)
 
     @request_id.setter
     def request_id(self, value):
@@ -34,24 +38,33 @@ class _Context:
     def trace(self, value):
         self._thread_local.trace = value
 
+    @trace_context.setter
+    def trace_context(self, value):
+        self._thread_local.trace_context = value
+
 
 ctx = _Context
 
 
 def set_request_id(request: Request, response: Response):
     cloud_trace_context = request.get_header('X-CLOUD-TRACE-CONTEXT', None)
-    request_id = cloud_trace_context.split('/')[0] if cloud_trace_context else None
 
-    if request_id:
-        ctx.request_id = request_id
-    else:
+    if not cloud_trace_context:
         ctx.request_id = str(uuid4())
+        
+        cloud_trace_context = \
+            f'{ctx.request_id}/{str(random.randint(1000000000000000000, 9999999999999999999))};o=1'
+    else:
+        ctx.request_id = cloud_trace_context.split('/')[0]
+    
+    ctx.trace = f"projects/{PROJECT_ID}/traces/{ctx.request_id}"
+    ctx.trace_context = cloud_trace_context
+    
+    request.context.cloud_trace_context = cloud_trace_context
+    request.context.trace = ctx.trace
 
     response.set_header('X-CLOUD-TRACE-CONTEXT', cloud_trace_context)
-    ctx.trace = f"projects/{PROJECT_ID}/traces/{ctx.request_id}"
 
-    request.context.trace = ctx.trace
-    if cloud_trace_context: request.context.cloud_trace_context = cloud_trace_context
 
     return
 
@@ -108,9 +121,13 @@ class logging():
 
         ctx.request_id = str(uuid4())
         ctx.trace = f"projects/{PROJECT_ID}/traces/{ctx.request_id}"
+        ctx.trace_context = f'{ctx.request_id}/{str(random.randint(1000000000000000000, 9999999999999999999))};o=1'
 
         return ctx.trace
-        # return f"projects/{PROJECT_ID}/traces/{ctx.trace}"
+    
+    @staticmethod
+    def get_trace_context() -> str:
+        return ctx.trace_context
 
     @staticmethod
     def info(message: dict):
@@ -143,3 +160,4 @@ class logging():
     @staticmethod
     def default(message: dict):
         logger.log_struct(message, trace=logging.get_trace(), severity="DEFAULT")
+
